@@ -1,19 +1,9 @@
 import json
-import os
 
 from .. import const
 from ..templates import templates
 
-
-def loadScripts():
-    with open(const.filename, 'rt') as s:
-        return json.load(s)['scripts']
-
-
-def runScriptDirectly(script):
-    print(f'\n\t> {script}\n')
-    os.system(script)
-
+from ..globals import *
 
 def addScript(name, command, description=""):
     with open(const.filename, 'rt') as s:
@@ -25,12 +15,17 @@ def addScript(name, command, description=""):
     print('Script added successfully.')
 
 
-def initialize(template):
-    schema = templates[template]
+def initialize(template_name,disable_oninit = False):
+    template = templates[template_name]
+    schema = template['body']
+    schema["version"] = '0.0.0'
+    oninit = template.get('oninit',None)
+    if oninit and not disable_oninit:
+        oninit()
     with open(const.filename, 'wt') as s:
         json.dump(schema, s)
     print('Successfully initialized ' +
-          const.filename+f' with {template} template.')
+          const.filename+f' with {template_name} template.')
 
 
 def removeScript(name):
@@ -41,13 +36,3 @@ def removeScript(name):
         json.dump(data, s)
     print('Script removed successfully.')
 
-
-def runScript(name):
-    scripts = loadScripts()
-    called_script = scripts.get(name, None)
-    cmd = called_script["command"]
-    if called_script:
-        print(f'\n\t> {cmd}\n')
-        os.system(cmd)
-    else:
-        raise Exception(f'Can not find script named "{name}"')
